@@ -64,6 +64,10 @@ public:
     Q_INVOKABLE QVariant fromBase64(const QString &s) const;
     /** Converts the given QByteArray into a BitArray. */
     Q_INVOKABLE QVariant toBitArray(const QVariant &b) const;
+    /** Converts the given QByteArray into a string for processing in JS.
+     *  This only works if there isn't "too much" binary content in the byte array.
+     */
+    Q_INVOKABLE QString byteArrayToString(const QVariant &b) const;
 
     ///@cond internal
     void setContextDate(const QDateTime &dt);
